bl_info = {
    "name": "Solid Boot",
    "author": "Cosmo Mídias",
    "version": (1, 0, 0),
    "blender": (2, 80, 0),
    "location": "Preferences > Add-ons",
    "description": "3D Views loaded in Solid Mode rather Material Preview",
    "category": "3D View",
    "doc_url": "https://www.cosmomidias.com"
}

import bpy
import sys
from bpy.types import Operator, AddonPreferences
from bpy.props import StringProperty

# Import custom icons
from .custom_icons import get_icon

class SOLIDBOOT_OT_open_url(Operator):
    bl_idname = "solidboot.open_url"
    bl_label = "Open URL"
    bl_description = "Open a web page in the default browser"
    
    url: StringProperty(default="")

    def execute(self, context):
        import webbrowser
        webbrowser.open(self.url)
        return {'FINISHED'}

class SolidBootPreferences(AddonPreferences):
    bl_idname = __name__

    def draw(self, context):
        layout = self.layout

        # INFO BOX
        box = layout.box()
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="About Solid Boot:")
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="This addon automatically sets all 3D views to Solid mode rather Material Preview.")
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="(When Blender starts or when new files are loaded)")
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="No configuration needed - just enable the addon and save the startup file.")

        # MARKETING
        box = layout.box()
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="We can help your Quality of Life & Performance!")
        # row.label(text="", icon_value=get_icon("icon_brokenheart"))

        row = box.row()
        row.alignment = 'CENTER'
        row.label(text="Meet other tools and consider supporting us!")

        row = box.row(align=True)
        row.operator(SOLIDBOOT_OT_open_url.bl_idname,
                    icon_value=get_icon("icon_gumroad"),
                    text='Simplify+ Add-on - Viewport Performance ').url = 'https://simplifyplus.cosmomidias.com/'

        row = box.row(align=True)
        row.operator(SOLIDBOOT_OT_open_url.bl_idname,
                    icon_value=get_icon("icon_gumroad"),
                    text='Magic Coordinate Add-on - Dynamic Mapping').url = 'https://cosmomidias.gumroad.com/l/magic-coordinate'

        row = box.row(align=True)
        row.operator(SOLIDBOOT_OT_open_url.bl_idname,
                    icon_value=get_icon("icon_gumroad"),
                    text='Pro Thunder - Lightning Effects').url = 'https://cosmomidias.gumroad.com/l/prothunder'


@bpy.app.handlers.persistent
def force_solid_view(dummy):
    wm = bpy.data.window_managers[0]
    for window in wm.windows:
        for area in window.screen.areas:
            if area.type == 'VIEW_3D':
                for space in area.spaces:
                    if space.type == 'VIEW_3D' and space.shading.type != 'WIREFRAME':
                        space.shading.type = 'SOLID'

def register():
    # Register custom icons first
    from .custom_icons import register as register_icons
    register_icons()
    
    # Check if handler isn't already registered
    if force_solid_view not in bpy.app.handlers.load_post:
        bpy.app.handlers.load_post.append(force_solid_view)
    
    bpy.utils.register_class(SOLIDBOOT_OT_open_url)
    bpy.utils.register_class(SolidBootPreferences)

def unregister():
    if force_solid_view in bpy.app.handlers.load_post:
        bpy.app.handlers.load_post.remove(force_solid_view)
    
    bpy.utils.unregister_class(SOLIDBOOT_OT_open_url)
    bpy.utils.unregister_class(SolidBootPreferences)
    
    # Unregister custom icons
    from .custom_icons import unregister as unregister_icons
    unregister_icons()

# For Blender 4.2+ extension system
if bpy.app.version >= (4, 2):
    from importlib import reload
    reload(sys.modules[__name__])

if __name__ == "__main__":
    register()